@@ -21,6 +21,7 @@
 #else
 #include <signal.h>
 #include <pwd.h>
+#include <grp.h>
 #include <fcntl.h>
 #endif
 #include <config.h>
@@ -760,10 +761,13 @@ static void usage(void)
         "  check                    Server deadlock check\n"
         "  concurrency <level>      Server concurrency level\n"
         "  digest id [realm [type]] Compute a digest\n"
+        "  disable conf-id...       Disable configurations\n"
         "  down                     Shut down server\n"
         "  drop <user|callid>       Drop an active call\n"
         "  dump                     Dump server configuration\n"
+        "  enable conf-id...        Enable configurations\n"
         "  events                   Display server events\n"
+        "  grant <group>            Grant dir access to system group\n"
         "  history [bufsize]        Set buffer or dump error log\n"
         "  ifup <iface>             Notify interface came up\n"
         "  ifdown <iface>           Notify interface went down\n"
@@ -908,6 +912,88 @@ static void message(char **argv)
     command(argv, 10);
 }
 
+#ifdef  HAVE_PWD_H
+static void grant(char **argv)
+{
+    gid_t gid = -1;
+    struct group *grp;
+    fsys::fileinfo_t ino;
+
+    if(!argv[1])
+        shell::errexit(1, "*** sipwitch: grant: no group specified\n");
+    if(argv[2])
+        shell::errexit(1, "*** sipwitch: grant: not more than one group\n");
+
+    grp = getgrnam(argv[1]);
+    if(grp)
+        gid = grp->gr_gid;
+    else if(atol(argv[1]))
+        gid = atol(argv[1]);
+    else
+        shell::errexit(2, "*** sipwitch: grant: %s: unknown group\n", argv[1]);
+
+    fsys::fileinfo(DEFAULT_VARPATH "/lib/sipwitch", &ino);
+    chmod(DEFAULT_VARPATH "/lib/sipwitch", ino.st_mode | 070);
+    chown(DEFAULT_VARPATH "/lib/sipwitch", ino.st_uid, gid);
+
+    fsys::fileinfo(DEFAULT_VARPATH "/cache/sipwitch", &ino);
+    chmod(DEFAULT_VARPATH "/cache/sipwitch", ino.st_mode | 070);
+    chown(DEFAULT_VARPATH "/cache/sipwitch", ino.st_uid, gid);
+
+    exit(0);
+}
+#else
+static void grant(char **argv)
+{
+    shell::errexit(9, "*** sipwitch: grant: unsupported platform");
+}
+#endif
+
+#ifdef  _MSWINDOWS_
+
+static void enable(char **argv)
+{
+    shell::errexit(9, "*** sipwitch: enable: unsupported platform");
+}
+
+static void disable(char **argv)
+{
+    shell::errexit(9, "*** sipwitch: disable: unsupported platform");
+}
+
+#else
+
+static void enable(char **argv)
+{
+    char source[128], target[128];
+
+    if(!argv[1])
+        shell::errexit(1, "*** sipwitch: enable: no configs specified\n");
+
+    while(*(++argv)) {
+        snprintf(source, sizeof(source), "%s/sipwitch.d/%s.xml", DEFAULT_CFGPATH, *argv);
+        snprintf(target, sizeof(target), "%s/lib/sipwitch/%s.xml", DEFAULT_VARPATH, *argv);
+        fsys::link(source, target);
+    }
+    exit(0);
+}
+
+static void disable(char **argv)
+{
+    char target[128];
+
+    if(!argv[1])
+        shell::errexit(1, "*** sipwitch: disable: no configs specified\n");
+
+    while(*(++argv)) {
+        snprintf(target, sizeof(target), "%s/lib/sipwitch/%s.xml", DEFAULT_VARPATH, *argv);
+        fsys::remove(target);
+    }
+    exit(0);
+}
+
+#endif
+
 PROGRAM_MAIN(argc, argv)
 {
     if(argc < 2)
@@ -960,8 +1046,15 @@ PROGRAM_MAIN(argc, argv)
             realm(argv);
     else if(eq(*argv, "drop"))
         drop(argv);
-    if(eq(*argv, "events"))
+    else if(eq(*argv, "grant"))
+        grant(argv);
+    else if(eq(*argv, "enable"))
+        enable(argv);
+    else if(eq(*argv, "disable"))
+        disable(argv);
+    else if(eq(*argv, "events"))
         showevents(argv);
+
     if(!argv[1])
         shell::errexit(1, "use: sipwitch command [arguments...]\n");
     else
